{% templatetag openblock %} extends "arctic/base.html" {% templatetag closeblock %}

{% templatetag openblock %} block content {% templatetag closeblock %}
    <h3>Welcome to Arctic!</h3>
    <br />
    <p>Congratulations, you have just created a skeleton Arctic project.</p>
    <p>You can now create some ListViews to display data, and perhaps some
        forms with custom layouts.</p>
    <p>Afterwards don't forget to setup user roles (if needed), and customize 
        your Arctic user interface.</p>
{% templatetag openblock %} endblock {% templatetag closeblock %}