<!DOCTYPE html>
<html lang="en">

    <head>
        <meta charset="utf-8">
        <title>Something went wrong!</title>
        <style>
            body {
                font-family: 'Helvetica Neue', 'Helvetica', 'Arial';
                font-size: 14px;
                line-height: 1.5;
                color: #666;
            }

            .page {
                margin: 80px auto;
                width: 400px;
            }
        </style>
    </head>

    <body>
        <div class="page">
            <h1>Something went wrong</h1>
            <p>
                Please inform support.
            </p>
        </div>
    </body>

</html>
