{% block confirm_dialog %}
<div class="modal fade" id="confirm-dialog" tabindex="-1" role="dialog"  aria-hidden="true">
  <div class="modal-dialog modal-dialog-centered" role="document">
    <div class="modal-content">
      <div class="modal-header">
        <h5 class="modal-title"></h5>
        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
          <span aria-hidden="true">&times;</span>
        </button>
      </div>
      <div class="modal-body"></div>
      <div class="modal-footer">
        <button type="button" class="btn btn-secondary confirm-cancel" data-dismiss="modal">Cancel</button>
        <a href="#" role="button" class="btn btn-primary confirm-ok">OK</a>
      </div>
    </div>
  </div>
</div>
{% endblock %}

{% block iframe_modal %}
<div class="modal fade" id="iframe-modal" tabindex="-1" role="dialog"  aria-hidden="true">
  <div class="modal-dialog modal-dialog-centered" role="document">
    <div class="modal-content">
      <iframe src="" width="100%" scrolling="no" style="overflow: hidden;"></iframe>
    </div>
  </div>
</div>
{% endblock %}
