<div class="row">
    <div class="col-12 {% if size %}col-sm-{{size}} {% else %}col-sm-2{% endif %}">
        <label for="{{ field.auto_id }}" class="{% if field.field.required %} required{% endif %}">
            {% include 'arctic/partials/form_field_parts/field_label.html' %}
        </label>
    </div>
    <div class="col-12 {% if size %}col-sm{{-12|add:size}} {% else %}col-sm-10{% endif %}">
        {{ field }}
    </div>
</div>
