{% if field.is_hidden %}
  {{ field }}
{% else %}
    {% comment %}
         Make the field widget type available to templates so we can
         mark-up checkboxes differently to other widgets.
    {% endcomment %}
    {% block control_group %}

        {% block controls %}
        <div class="{%if column %}col-sm-12 col-md-{{column}}{% endif %} col">
            <div class="form-group {% if field.errors %}invalid-form-field{% endif %}">
                {% block widget %}
                    {% if form_display == 'tabular' %}
                        {% include "arctic/partials/form_field_parts/form_field_tabular.html" %}
                    {% elif form_display == 'float-label' %}
                        {% include "arctic/partials/form_field_parts/form_field_float.html" %}
                    {% else %}
                        {# default #}
                        {% include "arctic/partials/form_field_parts/form_field_stacked.html" %}
                    {% endif %}
                {% endblock %}

                {% block errors %}
                    {% for error in field.errors %}
                        <span class="invalid-feedback">
                            {{ error }}
                        </span>
                    {% endfor %}
                {% endblock %}
            </div>
        </div>
        {% endblock %}
    {% endblock %}
{% endif %}
