{% extends "arctic/base.html" %}


{% load i18n staticfiles %}


{% block title %}
    {{ SITE_TITLE }} - Login
{% endblock %}


{% block body_class %}page-login{% endblock %}


{% block body %}
<div class="row justify-content-center">
    <div class="col-lg-4 col-sm-6 col">
        <div class="outer"><div class="middle"><div class="inner">
            <img class="page-login__logo" src="{% static SITE_LOGO %}"/>
            <h1 class="page-login__title">{{ SITE_NAME }}</h1>
            <form action=".?next={{ next }}" method="post" class="{{ form_display }}" novalidate>
                <fieldset type="get">
                    {% csrf_token %}
                    {% if messages %}
                        {% for message in messages %}
                            <div class="row login-message">
                                <div class="col">
                                    <div class="alert alert-danger" data-closable>
                                        {{ message }}
                                        <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                                            <span aria-hidden="true">&times;</span>
                                        </button>
                                    </div>
                                </div>
                            </div>
                        {% endfor %}
                    {% endif %}
                      <div class="log-in-form">
                            {% block form %}
                                {% block form_fields %}
                                    {% include "arctic/partials/form_fields.html" with form=form %}
                                {% endblock %}
                            {% endblock %}
                            <p><button type="submit" class="btn btn-primary btn-block">Login</button></p>
                        {% block login_extra %}
                        {% endblock %}
                      </div>
                </fieldset>
            </form>
        </div></div></div>
    </div>
</div>

{% endblock %}
