{% load i18n staticfiles  %}

<meta charset="utf-8">
<meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
<meta name="description" content="">
<meta name="author" content="">

{% if SITE_FAVICON %}
    <link rel="shortcut icon" href="{% static SITE_FAVICON %}"/>
{% endif %}

<title>
    {% block title %}
        {{ SITE_TITLE }} – {{ page_title }}
    {% endblock %}
</title>

{% block arctic_head_includes %}
<link href="{% static "arctic/dist/assets/css/arctic.css" %}" rel="stylesheet">
{{ media.css }}
{% endblock %}

{% block arctic_extra_head_includes %}{% endblock %}
<style>
    :root {
        {% if SIDEBAR_BACKGROUND %}
            --sidebar-background: {{SIDEBAR_BACKGROUND}};
        {% endif %}
        {% if SIDEBAR_COLOR %}
            --sidebar-color: {{SIDEBAR_COLOR}};
        {% endif %}
        {% if SIDEBAR_ALT_COLOR %}
            --sidebar-alt-color: {{SIDEBAR_ALT_COLOR}};
        {% endif %}
        {% if HIGHLIGHT_BACKGROUND %}
            --highlight-background: {{HIGHLIGHT_BACKGROUND}};
        {% endif %}
        {% if HIGHLIGHT_COLOR %}
            --highlight-color: {{HIGHLIGHT_COLOR}};
        {% endif %}
    }
    {% block arctic__extra_styles %}{% endblock %}
</style>
