# Generated by Django 2.0.6 on 2018-06-18 08:45

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('arctic', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='role',
            options={'ordering': ['name']},
        ),
        migrations.AlterModelOptions(
            name='userrole',
            options={'ordering': ['user']},
        ),
    ]
